<?php
/**
* @version 1.0.0
* @package RStickets! 1.0.0
* @copyright (C) 2007-2008 www.rsjoomla.com
* @license GPL, http://www.gnu.org/copyleft/gpl.html
*/

defined('_JEXEC') or die('Restricted access');

class menuRstickets {

	function _SETTINGS()
	{
		RST_adapter::menuStartTable();  
		RST_adapter::menuCustom( 'false', 'help.png', 'help_f2.png', RST_BACKEND_TOOLBAR_SUPPORT, false, "javascript:window.open('http://www.rsjoomla.com/index.php/Customer-Support.html');" );
		RST_adapter::menuSpacer();
		RST_adapter::menuCustom( '', 'preview.png', 'preview_f2.png', RST_BACKEND_TOOLBAR_MAIN, false );    
        RST_adapter::menuSpacer();
		RST_adapter::menuEndTable();
	}
	function _STAFF()
	{
		RST_adapter::menuStartTable();  
		RST_adapter::menuAddNewX( 'add_staff', LBL_NEW_STAFF);
		RST_adapter::menuSpacer(); 
		RST_adapter::menuCancel( '', RST_BACKEND_TOOLBAR_CLOSE);
		RST_adapter::menuSpacer(); 
		RST_adapter::menuCustom( 'false', 'help.png', 'help_f2.png', RST_BACKEND_TOOLBAR_SUPPORT, false, "javascript:window.open('http://www.rsjoomla.com/index.php/Customer-Support.html');" );
		RST_adapter::menuSpacer();
		RST_adapter::menuCustom( '', 'preview.png', 'preview_f2.png', RST_BACKEND_TOOLBAR_MAIN, false );    
        RST_adapter::menuSpacer();
		RST_adapter::menuEndTable();
	}
	
	function _ADD_STAFF()
	{
		RST_adapter::menuStartTable();  
		if($GLOBALS['showSaveStaff']){
			RST_adapter::menuCustom('false', 'save.png', 'save_f2.png', RST_BACKEND_TOOLBAR_SAVE, false, "javascript:document.add_staff.submit();return false;");
			RST_adapter::menuSpacer(); 
		}
		RST_adapter::menuCancel( 'staff', RST_BACKEND_TOOLBAR_CLOSE);
		RST_adapter::menuSpacer(); 
		RST_adapter::menuCustom( 'false', 'help.png', 'help_f2.png', RST_BACKEND_TOOLBAR_SUPPORT, false, "javascript:window.open('http://www.rsjoomla.com/index.php/Customer-Support.html');" );
		RST_adapter::menuSpacer();
		RST_adapter::menuCustom( '', 'preview.png', 'preview_f2.png', RST_BACKEND_TOOLBAR_MAIN, false );    
        RST_adapter::menuSpacer();
		RST_adapter::menuEndTable();
	}
	
	function _GROUPS()
	{
		RST_adapter::menuStartTable();  
		RST_adapter::menuAddNewX( 'add_group', LBL_NEW_GROUP);
		RST_adapter::menuSpacer(); 
		RST_adapter::menuCancel( '', RST_BACKEND_TOOLBAR_CLOSE);
		RST_adapter::menuSpacer(); 
		RST_adapter::menuCustom( 'false', 'help.png', 'help_f2.png', RST_BACKEND_TOOLBAR_SUPPORT, false, "javascript:window.open('http://www.rsjoomla.com/index.php/Customer-Support.html');" );
		RST_adapter::menuSpacer();
		RST_adapter::menuCustom( '', 'preview.png', 'preview_f2.png', RST_BACKEND_TOOLBAR_MAIN, false );    
        RST_adapter::menuSpacer();
		RST_adapter::menuEndTable();
	}
	function _ADD_GROUP()
	{
		RST_adapter::menuStartTable();  
		RST_adapter::menuCustom('false', 'save.png', 'save_f2.png', RST_BACKEND_TOOLBAR_SAVE, false, "javascript:if(validate_group(document.add_group)) document.add_group.submit();return false;");
		RST_adapter::menuSpacer(); 
		RST_adapter::menuCancel( 'groups', RST_BACKEND_TOOLBAR_CLOSE);
		RST_adapter::menuSpacer(); 
		RST_adapter::menuCustom( 'false', 'help.png', 'help_f2.png', RST_BACKEND_TOOLBAR_SUPPORT, false, "javascript:window.open('http://www.rsjoomla.com/index.php/Customer-Support.html');" );
		RST_adapter::menuSpacer();
		RST_adapter::menuCustom( '', 'preview.png', 'preview_f2.png', RST_BACKEND_TOOLBAR_MAIN, false );    
        RST_adapter::menuSpacer();
		RST_adapter::menuEndTable();
	}
	function _DEPARTMENTS()
	{
		RST_adapter::menuStartTable();  
		RST_adapter::menuAddNewX( 'add_department', LBL_NEW_DEPARTMENT);
		RST_adapter::menuSpacer(); 
		RST_adapter::menuCancel( '', RST_BACKEND_TOOLBAR_CLOSE);
		RST_adapter::menuSpacer(); 
		RST_adapter::menuCustom( 'false', 'help.png', 'help_f2.png', RST_BACKEND_TOOLBAR_SUPPORT, false, "javascript:window.open('http://www.rsjoomla.com/index.php/Customer-Support.html');" );
		RST_adapter::menuSpacer();
		RST_adapter::menuCustom( '', 'preview.png', 'preview_f2.png', RST_BACKEND_TOOLBAR_MAIN, false );    
        RST_adapter::menuSpacer();
		RST_adapter::menuEndTable();
	}
	function _ADD_DEPARTMENT()
	{
		RST_adapter::menuStartTable();  
		RST_adapter::menuCustom('false', 'save.png', 'save_f2.png', RST_BACKEND_TOOLBAR_SAVE, false, "javascript:if(validate_department(document.add_department)) document.add_department.submit();return false;");
		RST_adapter::menuSpacer(); 
		RST_adapter::menuCancel( 'departments', RST_BACKEND_TOOLBAR_CLOSE);
		RST_adapter::menuSpacer(); 
		RST_adapter::menuCustom( 'false', 'help.png', 'help_f2.png', RST_BACKEND_TOOLBAR_SUPPORT, false, "javascript:window.open('http://www.rsjoomla.com/index.php/Customer-Support.html');" );
		RST_adapter::menuSpacer();
		RST_adapter::menuCustom( '', 'preview.png', 'preview_f2.png', RST_BACKEND_TOOLBAR_MAIN, false );    
        RST_adapter::menuSpacer();
		RST_adapter::menuEndTable();
	}
	
	function _DEFAULT()
	{
		RST_adapter::menuStartTable();  
		RST_adapter::menuCustom( 'false', 'help.png', 'help_f2.png', RST_BACKEND_TOOLBAR_SUPPORT, false, "javascript:window.open('http://www.rsjoomla.com/index.php/Customer-Support.html');" );
		RST_adapter::menuSpacer();
		RST_adapter::menuCustom( '', 'preview.png', 'preview_f2.png', RST_BACKEND_TOOLBAR_MAIN, false );    
        RST_adapter::menuSpacer();
		RST_adapter::menuEndTable();
	}
}

?>